@@ -16,8 +16,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 __title__ = "eodag-cube"
-__description__ = "Data access for Earth Observation Data Access Gateway"
-__version__ = "0.1.0"
+__description__ = "Data access for EODAG"
+__version__ = "0.1.1"
 __author__ = "CS GROUP - France (CSSI)"
 __author_email__ = "admin@geostorm.eu"
 __url__ = "https://github.com/CS-SI/eodag-cube"
